@@ -1,9 +1,10 @@
 from dragg.aggregator import Aggregator
+from dragg.rl_aggregator import RLAggregator
 from dragg.reformat import Reformat
 
 if __name__ == "__main__":
 
-    a = Aggregator()
+    a = RLAggregator()
     a.run()
 
     # agg_params = {"alpha": [0.0625], "beta":[1.0], "epsilon":[0.05, 0.025], "rl_horizon":[], "mpc_disutility":[]} # set parameters from earlier runs
@@ -13,7 +14,7 @@ if __name__ == "__main__":
     # include_runs = {}
     # add_outputs = {}
 
-    r = Reformat(mpc_params={"mpc_discomfort":[]})
-    r.main() # use main to plot a suite of graphs
+    # r = Reformat(mpc_params={"mpc_discomfort":[]})
+    # r.main() # use main to plot a suite of graphs
     # r.save_images() # saves the images
     # r.rl2baseline() # specific plots available through named methods
